@@ -1,7 +1,7 @@
 #!/usr/bin/perl -W -T
 use strict;
 use Carp qw();
-use Package::Transporter::Generator::Homonymous_Tie;
+use Package::Transporter::Generator::Potential::Homonymous_Tie;
 
 # homonymous means the same name as the package file base name,
 # which is 'main' in this case (no package name set)
@@ -10,7 +10,7 @@ unless (-f 'main.dbm') {
 }
 
 use Package::Transporter sub{eval shift}, sub {
-	my $generator = Package::Transporter::Generator::Homonymous_Tie->new($_[0]);
+	my $generator = Package::Transporter::Generator::Potential::Homonymous_Tie->new($_[0]);
 	$generator->prototypes();
 	$_[0]->register_potential($generator, 'FOR_SELF');
 };
@@ -34,4 +34,4 @@ $sub_bodies{'yn'} = q{print STDOUT ($_[0] ? 'Yes' : 'No'), "\n";};
 $sub_bodies{'hello_world'} = q{print "Hello World.\n";};
 $sub_bodies{'hello_world-prototype'} = q{};
 $sub_bodies{'hola_mundo'} = q{print "Hola Mundo.\n";};
-$sub_bodies{'salut_monde'} = q{print "Salut Monde.\n";};
\ No newline at end of file
+$sub_bodies{'salut_monde'} = q{print "Salut Monde.\n";};
